@@ -2,15 +2,9 @@ use strict;
 use warnings;
 
 package Test::Deep::Methods;
-use Carp qw( confess );
 
 use Test::Deep::Cmp;
 
-use vars qw( @ISA );
-@ISA = qw( Test::Deep::Cmp );
-
-use Data::Dumper qw(Dumper);
-
 sub init
 {
 	my $self = shift;
@@ -34,35 +28,25 @@ sub init
 sub descend
 {
 	my $self = shift;
-	my $d1 = shift;
+	my $got = shift;
 
-	my $ok = 1;
-
-	my %data = (type => $self);
-
-	$Test::Deep::Stack->push(\%data);
+	my $data = $self->data;
 
 	foreach my $method (@{$self->{methods}})
 	{
-		$data{method} = $method;
+		$data->{method} = $method;
 
-		my ($call, $expected) = @$method;
+		my ($call, $exp_res) = @$method;
 		my ($name, @args) = @$call;
 
-		my $got = UNIVERSAL::can($d1, $name) ? $d1->$name(@args) : $Test::Deep::DNE;
+		my $got_res = UNIVERSAL::can($got, $name) ? $got->$name(@args) : $Test::Deep::DNE;
 
-		$ok = Test::Deep::descend($got, $expected);
+		next if Test::Deep::descend($got_res, $exp_res);
 
-		if (! $ok)
-		{
-			$data{vals} = [$got, $expected];
-			last;
-		}
+		return 0;
 	}
 
-	$Test::Deep::Stack->pop if $ok;
-
-	return $ok;
+	return 1;
 }
 
 sub render_stack
@@ -80,13 +64,4 @@ sub render_stack
 	return $var;
 }
 
-sub compare
-{
-	my $self = shift;
-
-	my $other = shift;
-
-	return Test::Deep::descend($self->{methods}, $other->{methods});
-}
-
 1;
